@@ -12,6 +12,8 @@ __all__ = [
 
 
 def copy_func(f: F) -> FunctionType:
+    """Try copying a function."""
+
     try:
         g = FunctionType(
             f.__code__, f.__globals__, name=f.__name__, argdefs=f.__defaults__, closure=f.__closure__
@@ -24,6 +26,8 @@ def copy_func(f: F) -> FunctionType:
 
 
 def erase_module(func: F, *, vs_only: bool = False) -> F:
+    """Delete the __module__ of the function."""
+
     if hasattr(func, '__module__') and (
         func.__module__ == '__vapoursynth__' if vs_only else True
     ):
